@@ -28,10 +28,11 @@ per each session.
 Sequence names on the scanner must follow this specification to avoid manual
 conversion/handling:
 
-  [PREFIX:]<seqtype[-label]>[_ses-<SESID>][_task-<TASKID>][_acq-<ACQLABEL>][_run-<RUNID>][_dir-<DIR>][<more BIDS>][__<custom>]
+  [PREFIX:][WIP ]<seqtype[-label]>[_ses-<SESID>][_task-<TASKID>][_acq-<ACQLABEL>][_run-<RUNID>][_dir-<DIR>][<more BIDS>][__<custom>]
 
 where
  [PREFIX:] - leading capital letters followed by : are stripped/ignored
+ [WIP ] - prefix is stripped/ignored (added by Philips for patch sequences)
  <...> - value to be entered
  [...] - optional -- might be nearly mandatory for some modalities (e.g.,
          run for functional) and very optional for others
@@ -104,6 +105,16 @@ __<custom> (optional)
 
 Although we still support "-" and "+" used within SESID and TASKID, their use is
 not recommended, thus not listed here
+
+## Scanner specifics
+
+We perform following actions regardless of the type of scanner, but applied
+generally to accommodate limitations imposed by different manufacturers/models:
+
+### Philips
+
+- We replace all ( with { and ) with } to be able e.g. to specify session {date}
+- "WIP " prefix unconditionally added by the scanner is stripped
 """
 
 import os
@@ -115,7 +126,7 @@ from glob import glob
 import logging
 lgr = logging.getLogger('heudiconv')
 
-# Terminology to hamornise and use to name variables etc
+# Terminology to harmonise and use to name variables etc
 # experiment
 #  subject
 #   [session]
@@ -159,9 +170,9 @@ protocols2fix = {
     # QA
     '43b67d9139e8c7274578b7451ab21123':
         [
-         #('anat-scout.*', 'anat-scout_ses-{date}'),
+         # ('anat-scout.*', 'anat-scout_ses-{date}'),
          # do not change it so we retain _ses-{date}
-         #('anat-scout.*', 'anat-scout'),
+         # ('anat-scout.*', 'anat-scout'),
          ('BOLD_p2_s4_3\.5mm', 'func_task-rest_acq-p2-s4-3.5mm'),
          ('BOLD_p2_s4',        'func_task-rest_acq-p2-s4'),
          ('BOLD_p2_noprescannormalize', 'func-bold_task-rest_acq-p2noprescannormalize'),
@@ -243,7 +254,7 @@ protocols2fix = {
         [
             ('fmap_acq-discorr-dti-', 'fmap_acq-dwi_dir-'),
         ],
-    #'022969bfde39c2940c114edf1db3fabc':
+    # '022969bfde39c2940c114edf1db3fabc':
     #    [  # should be applied only for ses-03!
     #        ('_acq-MPRAGE_ses-02', '_acq-MPRAGE_ses-03'),
     #    ],
@@ -251,14 +262,14 @@ protocols2fix = {
     # fix per accession yet
     #    '23763823d2b9b4b09dafcadc8e8edf21':
     #        [
-    #            ('anat-T1w_acq-MPRAGE', 'anat-T1w_acq-MPRAGE_run-06'), 
+    #            ('anat-T1w_acq-MPRAGE', 'anat-T1w_acq-MPRAGE_run-06'),
     #            ('anat_T2w', 'anat_T2w_run-06'),
     #            ('fmap_acq-3mm', 'fmap_acq-3mm_run-06'),
     #        ],
 }
 # there was also screw up in the locator specification
 # so we need to fix in both
-#protocols2fix['67ae5e641ea9d487b6fdf56fb91aeb93'] = protocols2fix['022969bfde39c2940c114edf1db3fabc']
+# protocols2fix['67ae5e641ea9d487b6fdf56fb91aeb93'] = protocols2fix['022969bfde39c2940c114edf1db3fabc']
 
 # list containing StudyInstanceUID to skip -- hopefully doesn't happen too often
 dicoms2skip = [
@@ -268,8 +279,8 @@ dicoms2skip = [
 
 DEFAULT_FIELDS = {
     # Let it just be in each json file extracted
-    #'Manufacturer': "Siemens",
-    #'ManufacturersModelName': "Prisma",
+    # 'Manufacturer': "Siemens",
+    # 'ManufacturersModelName': "Prisma",
     "Acknowledgements":
         "We thank Terry Sacket and the rest of the DBIC (Dartmouth Brain Imaging "
         "Center) personnel for assistance in data collection, and "
@@ -349,11 +360,13 @@ def md5sum(string):
     m = hashlib.md5(string.encode())
     return m.hexdigest()
 
+
 def get_study_description(seqinfo):
     # Centralized so we could fix/override
     v = get_unique(seqinfo, 'study_description')
     return v
 
+
 def get_study_hash(seqinfo):
     # XXX: ad hoc hack
     return md5sum(get_study_description(seqinfo))
@@ -416,8 +429,8 @@ def fix_seqinfo(seqinfo):
 
 def ls(study_session, seqinfo):
     """Additional ls output for a seqinfo"""
-    #assert len(sequences) <= 1  # expecting only a single study here
-    #seqinfo = sequences.keys()[0]
+    # assert len(sequences) <= 1  # expecting only a single study here
+    # seqinfo = sequences.keys()[0]
     return ' study hash: %s' % get_study_hash(seqinfo)
 
 
@@ -426,19 +439,17 @@ def ls(study_session, seqinfo):
 # So we just need subdir and file_suffix!
 def infotodict(seqinfo):
     """Heuristic evaluator for determining which runs belong where
-    
-    allowed template fields - follow python string module: 
-    
-    item: index within category 
-    subject: participant id 
+
+    allowed template fields - follow python string module:
+
+    item: index within category
+    subject: participant id
     seqitem: run number during scanning
     subindex: sub index within group
     session: scan index for longitudinal acq
     """
-
     seqinfo = fix_seqinfo(seqinfo)
     lgr.info("Processing %d seqinfo entries", len(seqinfo))
-    and_dicom = ('dicom', 'nii.gz')
 
     info = OrderedDict()
     skipped, skipped_unknown = [], []
@@ -461,7 +472,7 @@ def infotodict(seqinfo):
 
         template = None
         suffix = ''
-        seq = []
+        # seq = []
 
         # figure out type of image from s.image_info -- just for checking ATM
         # since we primarily rely on encoded in the protocol name information
@@ -541,9 +552,12 @@ def infotodict(seqinfo):
             if not dcm_image_iod_spec:
                 raise ValueError("Do not know image data type yet to make decision")
             seqtype_label = {
-                'M': 'magnitude',  # might want explicit {file_index}  ?
+                # might want explicit {file_index}  ?
+                # _epi for pepolar fieldmaps, see
+                # https://bids-specification.readthedocs.io/en/stable/04-modality-specific-files/01-magnetic-resonance-imaging-data.html#case-4-multiple-phase-encoded-directions-pepolar
+                'M': 'epi' if 'dir' in series_info else 'magnitude',
                 'P': 'phasediff',
-                'DIFFUSION': 'epi', # according to KODI those DWI are the EPIs we need
+                'DIFFUSION': 'epi',  # according to KODI those DWI are the EPIs we need
             }[dcm_image_iod_spec]
 
         # label for dwi as well
@@ -600,17 +614,28 @@ def infotodict(seqinfo):
         if s.is_motion_corrected and 'rec-' in series_info.get('bids', ''):
             raise NotImplementedError("want to add _acq-moco but there is _acq- already")
 
+        def from_series_info(name):
+            """A little helper to provide _name-value if series_info knows it
+
+            Returns None otherwise
+            """
+            if series_info.get(name):
+                return "%s-%s" % (name, series_info[name])
+            else:
+                return None
+
         suffix_parts = [
-            None if not series_info.get('task') else "task-%s" % series_info['task'],
-            None if not series_info.get('acq') else "acq-%s" % series_info['acq'],
+            from_series_info('task'),
+            from_series_info('acq'),
             # But we want to add an indicator in case it was motion corrected
             # in the magnet. ref sample  /2017/01/03/qa
             None if not s.is_motion_corrected else 'rec-moco',
+            from_series_info('dir'),
             series_info.get('bids'),
             run_label,
             seqtype_label,
         ]
-        # filter tose which are None, and join with _
+        # filter those which are None, and join with _
         suffix = '_'.join(filter(bool, suffix_parts))
 
         # # .series_description in case of
@@ -712,9 +737,9 @@ def get_unique(seqinfos, attr):
     return values.pop()
 
 
-# TODO: might need to do groupping per each session and return here multiple
+# TODO: might need to do grouping per each session and return here multiple
 # hits, or may be we could just somehow demarkate that it will be multisession
-# one and so then later value parsed (again) in infotodict  would be used???
+# one and so then later value parsed (again) in infotodict would be used???
 def infotoids(seqinfos, outdir):
     # decide on subjid and session based on patient_id
     lgr.info("Processing sequence infos to deduce study/session")
@@ -764,7 +789,7 @@ def infotoids(seqinfos, outdir):
         # although we might want an explicit '=' to note the same session as
         # mentioned before?
         if len(nonsign_vals) > 1:
-            lgr.warning( #raise NotImplementedError(
+            lgr.warning(  # raise NotImplementedError(
                 "Cannot deal with multiple sessions in the same study yet!"
                 " We will process until the end of the first session"
             )
@@ -786,7 +811,7 @@ def infotoids(seqinfos, outdir):
             # ... actually the same as with nonsign_vals, we just would need to figure
             # out initial one if sign ones, and should make use of knowing
             # outdir
-            #raise NotImplementedError()
+            # raise NotImplementedError()
             # we need to look at what sessions we already have
             sessions_dir = os.path.join(outdir, locator, 'sub-' + subject)
             prior_sessions = sorted(glob(os.path.join(sessions_dir, 'ses-*')))
@@ -804,7 +829,6 @@ def infotoids(seqinfos, outdir):
             else:
                 session = '001'
 
-
     if study_description_hash == '9d148e2a05f782273f6343507733309d':
         session = 'siemens1'
         lgr.info('Imposing session {0}'.format(session))
@@ -841,6 +865,7 @@ def parse_series_spec(series_spec):
     # https://github.com/ReproNim/reproin/issues/14
     # where PU: prefix is added by the scanner
     series_spec = re.sub("^[A-Z]*:", "", series_spec)
+    series_spec = re.sub("^WIP ", "", series_spec)  # remove Philips WIP prefix
 
     # Remove possible suffix we don't care about after __
     series_spec = series_spec.split('__', 1)[0]
@@ -888,9 +913,11 @@ def parse_series_spec(series_spec):
 
         # sanitize values, which must not have _ and - is undesirable ATM as well
         # TODO: BIDSv2.0 -- allows "-" so replace with it instead
-        value = str(value).replace('_', 'X').replace('-', 'X')
+        value = str(value) \
+            .replace('_', 'X').replace('-', 'X') \
+            .replace('(', '{').replace(')', '}')  # for Philips
 
-        if key in ['ses', 'run', 'task', 'acq']:
+        if key in ['ses', 'run', 'task', 'acq', 'dir']:
             # those we care about explicitly
             regd[{'ses': 'session'}.get(key, key)] = sanitize_str(value)
         else:
